# Machine Learning Wrappers SDK for Python

### This package has been tested with Python 3.8, 3.9 and 3.10

The Machine Learning Wrappers SDK provides a unified wrapper for various ML frameworks - to have one uniform scikit-learn format predict and predict_proba functions.

Highlights of the package include:

- A dataset wrapper to handle scipy sparse, pandas and numpy datasets in a uniform manner.
- A model wrapper to handle models from various frameworks uniformly, including scikit-learn, tensorflow, pytorch, lightgbm and xgboost

Please see the github website for the documentation and sample notebooks:
https://github.com/microsoft/ml-wrappers
